@@ -51,7 +51,11 @@ class GridSpec:
     transform: Affine
 
     crs: CRS = attr.ib(
-        metadata=dict(doc_exclude=True), default=None, hash=False, cmp=False
+        metadata=dict(doc_exclude=True),
+        default=None,
+        hash=False,
+        eq=False,
+        order=False,
     )
 
     @classmethod
